﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;

namespace UGTimerSpontaneousRowActivation
{
  public partial class Form1 : Form
  {
    private readonly BindingList<Trailer> _ugTransfersDataSource;

    public Form1()
    {
      InitializeComponent();

      _ugTransfersDataSource = GenerateTrailers();

      ugTrailers.DataSource = _ugTransfersDataSource;
      ugTrailers.Rows.ExpandAll(true);

      tmrTimeAtLocation.Start();
    }

    private static IEnumerable<Shipment> GenerateShipments(int count)
    {
      var rand = new Random();

      for (var i = 0; i < count; i++)
      {
        yield return new Shipment
        {
          ShipmentNumber = rand.Next(001000000, 352999999).ToString(),
          Weight = rand.Next(500, 5000)
        };
      }
    }

    private static BindingList<Trailer> GenerateTrailers()
    {
      return new BindingList<Trailer>
      {
        new Trailer
        {
          TrailerNumber = "12345",
          Shipments = GenerateShipments(10).ToList(),
          Arrived = DateTime.Now.AddHours(-4)
        },
        new Trailer
        {
          TrailerNumber = "98765",
          Shipments = GenerateShipments(7).ToList(),
          Arrived = DateTime.Now.AddHours(-2)
        }
      };
    }

    private void tmrTimeAtLocation_Tick(object sender, EventArgs e)
    {
      foreach (var trailer in _ugTransfersDataSource)
      {
        trailer.TimeAtLocation = DateTime.Now - trailer.Arrived;
      }
    }

    private void ugTrailers_InitializeLayout(object sender, InitializeLayoutEventArgs e)
    {
      e.Layout.Bands[0].Columns["Arrived"].Format = @"MM/dd hh:mm";
    }
  }
}